# exp1572

Game "1572: The Lost Expedition" (designed by [Mike Heim](https://boardgamegeek.com/boardgamedesigner/87601/mike-heim)).

Console game manager written in python. See full description at [BoardGameGeek](https://boardgamegeek.com/boardgame/199269/1572-lost-expedition).

This is a one page (print-and-play, PnP), ultra-portable, black and white solitaire game. You assume the role of a small party of conquistadors trying to reach the Atlantic Ocean after a failed expedition deep in the New World. This game is limited to 42 turns and each turn consists of phases such as Map Making, Exploring, and Hunting where a handful of dice are allocated in a press-your-luck fashion. For those that enjoy role-playing, there is also an optional Journaling phase where you try to tell a story about what happened on your turn. Can you reach the Atlantic Ocean before time runs out or before you lose all of your Conquistadors?

![Expedition Map](https://github.com/witdba/exp1572/raw/master/exp1572/docs/maps/1572_The_Lost_Expedition_EN.jpg)

## Install

```bash
pip install exp1572
```

## Run

```bash
exp1572
```

Available localizations: ru, en (work continues)
